@@ -11,6 +11,6 @@ function(lmom) {
     }
     para[2] <- 2*lmom$L2
     para[1] <- lmom$L1 - para[2]
-    return(list(type = 'exp', para = para))
+    return(list(type = 'exp', para = para, source="parexp"))
 }
 
